Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(524)

Unified Diff: pkg/polymer/lib/deserialize.dart

Issue 30183005: port polymer - 00e2982c78fcd396adaebff3118e94029a2b9fb0 (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/polymer/lib/src/boot.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/polymer/lib/deserialize.dart
diff --git a/pkg/polymer/lib/deserialize.dart b/pkg/polymer/lib/deserialize.dart
index 9de4ea99db4e2c1457233146b6d1236b8285ab92..0abd1b1c59bcdf3d4bc72921c8fd4cb647442f40 100644
--- a/pkg/polymer/lib/deserialize.dart
+++ b/pkg/polymer/lib/deserialize.dart
@@ -30,11 +30,11 @@ final _typeHandlers = () {
}();
/**
* Convert representation of [value] based on type of [defaultValue].
*/
-Object deserializeValue(String value, Object defaultValue, TypeMirror type) {
+Object deserializeValue(String value, Object currentValue, TypeMirror type) {
var handler = _typeHandlers[type.qualifiedName];
- if (handler != null) return handler(value, defaultValue);
+ if (handler != null) return handler(value, currentValue);
try {
// If the string is an object, we can parse is with the JSON library.
« no previous file with comments | « no previous file | pkg/polymer/lib/src/boot.dart » ('j') | no next file with comments »
@@ -30,11 +30,11 @@ final _typeHandlers = () {
}();
/**
- * Convert representation of [value] based on type of [defaultValue].
+ * Convert representation of [value] based on type of [currentValue].
*/

Powered by Google App Engine
This is Rietveld 408576698